==> huaweicloudsdkobs-3.1.131-py2.py3-none-any.whl: huaweicloudsdkobs/v1/model/filter_object.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class FilterObject:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    xml_name = "FilterObject"

    sensitive_list = []

    openapi_types = {
        'filter_rule': 'list[FilterRule]'
    }

    attribute_map = {
        'filter_rule': 'FilterRule'
    }

    def __init__(self, filter_rule=None):
        """FilterObject

        The model defined in huaweicloud sdk

        :param filter_rule: 
        :type filter_rule: list[:class:`huaweicloudsdkobs.v1.FilterRule`]
        """
        
        

        self._filter_rule = None
        self.discriminator = None

        if filter_rule is not None:
            self.filter_rule = filter_rule

    @property
    def filter_rule(self):
        """Gets the filter_rule of this FilterObject.

        :return: The filter_rule of this FilterObject.
        :rtype: list[:class:`huaweicloudsdkobs.v1.FilterRule`]
        """
        return self._filter_rule

    @filter_rule.setter
    def filter_rule(self, filter_rule):
        """Sets the filter_rule of this FilterObject.

        :param filter_rule: The filter_rule of this FilterObject.
        :type filter_rule: list[:class:`huaweicloudsdkobs.v1.FilterRule`]
        """
        self._filter_rule = filter_rule

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FilterObject):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkobs-3.1.148-py2.py3-none-any.whl: huaweicloudsdkobs/v1/model/filter_object.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class FilterObject:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    xml_name = "FilterObject"

    sensitive_list = []

    openapi_types = {
        'filter_rule': 'list[FilterRule]'
    }

    attribute_map = {
        'filter_rule': 'FilterRule'
    }

    def __init__(self, filter_rule=None):
        r"""FilterObject

        The model defined in huaweicloud sdk

        :param filter_rule: 
        :type filter_rule: list[:class:`huaweicloudsdkobs.v1.FilterRule`]
        """
        
        

        self._filter_rule = None
        self.discriminator = None

        if filter_rule is not None:
            self.filter_rule = filter_rule

    @property
    def filter_rule(self):
        r"""Gets the filter_rule of this FilterObject.

        :return: The filter_rule of this FilterObject.
        :rtype: list[:class:`huaweicloudsdkobs.v1.FilterRule`]
        """
        return self._filter_rule

    @filter_rule.setter
    def filter_rule(self, filter_rule):
        r"""Sets the filter_rule of this FilterObject.

        :param filter_rule: The filter_rule of this FilterObject.
        :type filter_rule: list[:class:`huaweicloudsdkobs.v1.FilterRule`]
        """
        self._filter_rule = filter_rule

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FilterObject):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
